=====================================================
Marmot: Ensemble modeling with hyperparameter tuner
=====================================================

.. image:: https://travis-ci.org/horoiwa/marmot.svg?branch=master
    :target: https://travis-ci.org/horoiwa/marmot


Overview
========


Key Features
============

- Ready to use ensemble models extended from sklearn

- Rapid hyperparameter tuning powered by `optuna`


Getting started
===============

Example: Boston housing dataset
